@@ -646,12 +646,13 @@ class ExFormat:
              'text_wrap':True})
 
     @staticmethod
-    def tf(workbook):
-        return workbook.add_format({'border':1,'font_name':'Microsoft Yahei','num_format':'#,##0.0'})
+    def tf(workbook,n):
+        num_format = ('#,##0.' + '0' * n) if n > 0 else '#,##0'
+        return workbook.add_format({'border':1,'font_name':'Microsoft Yahei','num_format':num_format})
 
     @staticmethod
-    def pf(workbook):
-        return workbook.add_format({'border':1,'font_name':'Microsoft Yahei','num_format':'0.0%'})
+    def pf(workbook,n):
+        return workbook.add_format({'border':1,'font_name':'Microsoft Yahei','num_format':f'0.{"0" * n}%'})
 
     @staticmethod
     def baf():
